# morphosamplers

[![License](https://img.shields.io/pypi/l/morphosamplers.svg?color=green)](https://github.com/kevinyamauchi/morphosamplers/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/morphosamplers.svg?color=green)](https://pypi.org/project/morphosamplers)
[![Python Version](https://img.shields.io/pypi/pyversions/morphosamplers.svg?color=green)](https://python.org)
[![CI](https://github.com/morphometrics/morphosamplers/actions/workflows/ci.yml/badge.svg)](https://github.com/morphometrics/morphosamplers/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/morphometrics/morphosamplers/branch/main/graph/badge.svg)](https://codecov.io/gh/morphometrics/morphosamplers)

A library for sampling image data along morphological objects such as splines and surfaces.
